@@ -23,10 +23,13 @@ var annotated_dup =
     [ "jsStreamSource", "structjs_stream_source.html", "structjs_stream_source" ],
     [ "jsStreamSourceInfo", "structjs_stream_source_info.html", "structjs_stream_source_info" ],
     [ "jsStreamState", "structjs_stream_state.html", "structjs_stream_state" ],
+    [ "jsStreamStateSubject", "structjs_stream_state_subject.html", "structjs_stream_state_subject" ],
+    [ "jsStreamStateSubjects", "structjs_stream_state_subjects.html", "structjs_stream_state_subjects" ],
     [ "jsSubOptions", "structjs_sub_options.html", "structjs_sub_options" ],
     [ "kvConfig", "structkv_config.html", "structkv_config" ],
     [ "kvEntryList", "structkv_entry_list.html", "structkv_entry_list" ],
     [ "kvKeysList", "structkv_keys_list.html", "structkv_keys_list" ],
+    [ "kvPurgeOptions", "structkv_purge_options.html", "structkv_purge_options" ],
     [ "kvWatchOptions", "structkv_watch_options.html", "structkv_watch_options" ],
     [ "natsMsgList", "structnats_msg_list.html", "structnats_msg_list" ]
 ];
\ No newline at end of file
