@@ -25,6 +25,8 @@ var nats_8h =
     [ "jsStreamSource", "group__types_group.html#gab4c43c87d81917aab748a50eee028449", null ],
     [ "jsStreamConfig", "group__types_group.html#ga26fd6a73df327ca3c271e46ddefc8acf", null ],
     [ "jsLostStreamData", "group__types_group.html#gaf80828510450faf84bbf456e94f5b784", null ],
+    [ "jsStreamStateSubject", "group__types_group.html#ga55dce2fa9ecd215716cc9ceece7dfefa", null ],
+    [ "jsStreamStateSubjects", "group__types_group.html#gae8b57d9c40364f97a705f3e61a1156b0", null ],
     [ "jsStreamState", "group__types_group.html#ga2bfd6de6ffc84d767482b3dd57cb9271", null ],
     [ "jsPeerInfo", "group__types_group.html#ga1e938dab794089f9329d7b7ece8f3e9b", null ],
     [ "jsClusterInfo", "group__types_group.html#gaaf92318ce94a1ae3547c9a7af5a3f4f6", null ],
@@ -49,6 +51,7 @@ var nats_8h =
     [ "kvWatcher", "group__types_group.html#ga526fa6d37e818784b94cdc1713f3a043", null ],
     [ "kvConfig", "group__types_group.html#ga6d594b091b4bb46192336413066a8edf", null ],
     [ "kvWatchOptions", "group__types_group.html#gac32f992fe797a1f7befc7dc3452640b6", null ],
+    [ "kvPurgeOptions", "group__types_group.html#ga90e8de23c4468005488bde690a2ffe9d", null ],
     [ "kvEntryList", "group__types_group.html#ga0125d394a3cbae2a1713eed8fab7f78e", null ],
     [ "kvKeysList", "group__types_group.html#gab36492d9d4370337cfed80edce4144e0", null ],
     [ "stanConnection", "group__types_group.html#ga9e826493769d23086cfccefe95cdf64c", null ],
@@ -177,6 +180,7 @@ var nats_8h =
     [ "natsOptions_SetNKeyFromSeed", "group__opts_group.html#ga696f02e0493c00d3c1eafff45b62b68e", null ],
     [ "natsOptions_SetWriteDeadline", "group__opts_group.html#gaafda5fb8d9ee3a17bd475ceaecfac218", null ],
     [ "natsOptions_DisableNoResponders", "group__opts_group.html#ga192465163abb87ad48a843b45cdf9984", null ],
+    [ "natsOptions_SetCustomInboxPrefix", "group__opts_group.html#gac5173473a731a4a36d15346fedddf91f", null ],
     [ "natsOptions_Destroy", "group__opts_group.html#ga93d8068cd6fff53b7f8e1c403db45eb9", null ],
     [ "stanConnOptions_Create", "group__stan_conn_opts_group.html#gaff52a1ce90253b4bdbb0005fca4f71b6", null ],
     [ "stanConnOptions_SetURL", "group__stan_conn_opts_group.html#ga3c6d511fc1e1febcdf5344960de5a0b3", null ],
@@ -316,6 +320,7 @@ var nats_8h =
     [ "jsStreamInfo_Destroy", "group__js_assets_group.html#ga8ee87ef86e94be42685941abe9638bbd", null ],
     [ "jsConsumerConfig_Init", "group__js_assets_group.html#ga3381bb05c05bf4a8979adde68d37dd66", null ],
     [ "js_AddConsumer", "group__js_assets_group.html#gaf2efb63db150e782d9007090b49d4115", null ],
+    [ "js_UpdateConsumer", "group__js_assets_group.html#gad13ec256e24710bb237995814871e554", null ],
     [ "js_GetConsumerInfo", "group__js_assets_group.html#ga2dda04757b4ab27a794b64f8d727fe23", null ],
     [ "js_DeleteConsumer", "group__js_assets_group.html#ga52fbc61759b11494db91f348a733c490", null ],
     [ "jsConsumerInfo_Destroy", "group__js_assets_group.html#ga9c1d5ed2f24ba836c10e415231f80088", null ],
@@ -334,12 +339,14 @@ var nats_8h =
     [ "js_SubscribeSync", "group__js_sub_group.html#gabacb010031e535f9fb6e2167337e8adf", null ],
     [ "js_PullSubscribe", "group__js_sub_group.html#gaaeaddb73857aa4eb4901eec945ed27cd", null ],
     [ "natsSubscription_Fetch", "group__js_sub_group.html#gafc5e0d2269bd23b4d5fb7f3b05278e50", null ],
+    [ "natsSubscription_GetConsumerInfo", "group__js_sub_group.html#gaae716a1431db065744c079b71a9f4c2e", null ],
     [ "natsSubscription_GetSequenceMismatch", "group__js_sub_group.html#ga0daed9f0d2d00cb14314ecc180a6fa84", null ],
     [ "natsMsg_GetMetaData", "group__js_msg.html#gacf48e59038fab35849e9dc6f8fcf6328", null ],
     [ "jsMsgMetaData_Destroy", "group__js_msg.html#gaf9bf92294342bcb27053de7038606d12", null ],
     [ "natsMsg_Ack", "group__js_msg.html#gae454fb7e7097a3cd3362cb49ef8a3c84", null ],
     [ "natsMsg_AckSync", "group__js_msg.html#gafb899ebf8e89b3a858fe20f7853635a7", null ],
     [ "natsMsg_Nak", "group__js_msg.html#gac271b874154301da9759f9ac05768b47", null ],
+    [ "natsMsg_NakWithDelay", "group__js_msg.html#gac0697389fa60a3c4725e53cd23ada7bd", null ],
     [ "natsMsg_InProgress", "group__js_msg.html#gae1e0beb19cd76e2f69e6415c41c9bb39", null ],
     [ "natsMsg_Term", "group__js_msg.html#gae84d21e4388255e9d990e53c9f67e7c4", null ],
     [ "natsMsg_GetSequence", "group__js_msg.html#ga819be2990ec20b964aa574b5331d7f2e", null ],
@@ -360,6 +367,7 @@ var nats_8h =
     [ "kvEntry_Operation", "group__kv_entry.html#ga088fd67d3d384ad7a7ddfc82535becea", null ],
     [ "kvEntry_Destroy", "group__kv_entry.html#ga8359ffcdeefb9c5821e6442d0d5ee388", null ],
     [ "kvStore_Get", "group__kv_group.html#ga2db86f80d6bfce1bdbedf1b9da22913c", null ],
+    [ "kvStore_GetRevision", "group__kv_group.html#ga9bf43431bb8264a3ea1f0df401afbe1a", null ],
     [ "kvStore_Put", "group__kv_group.html#ga1fdf7a1d3acf96e475184790589a401e", null ],
     [ "kvStore_PutString", "group__kv_group.html#ga84ebd66a95ce857765d4a16ec35daba9", null ],
     [ "kvStore_Create", "group__kv_group.html#ga5289f7cd3999cfb46fb1fcb83178aec6", null ],
@@ -367,9 +375,10 @@ var nats_8h =
     [ "kvStore_Update", "group__kv_group.html#gae0c593bb2ef94ae60e775617c9423038", null ],
     [ "kvStore_UpdateString", "group__kv_group.html#ga13ed70f15cd1485cd15f96bcc4b7ad1c", null ],
     [ "kvStore_Delete", "group__kv_group.html#ga68101d46739ca894fd7c56c8661c08d8", null ],
-    [ "kvStore_Purge", "group__kv_group.html#ga642970938345ee6b98ce3d9230034b36", null ],
+    [ "kvStore_Purge", "group__kv_group.html#ga3d5fa3d895d0d3041440105b244e9ca9", null ],
     [ "kvWatchOptions_Init", "group__kv_group.html#ga762fd5de8cde683e46a6736a51e575f5", null ],
-    [ "kvStore_PurgeDeletes", "group__kv_group.html#ga8870506415465a7272b4fe6902c0aec3", null ],
+    [ "kvPurgeOptions_Init", "group__kv_group.html#ga243113fd7df34ce104850ab888f04021", null ],
+    [ "kvStore_PurgeDeletes", "group__kv_group.html#ga34ab74b229ff88e64301ea53a274da69", null ],
     [ "kvStore_Watch", "group__kv_group.html#ga30feca870f580c7b9d2ad07a740505b2", null ],
     [ "kvStore_WatchAll", "group__kv_group.html#gaf011f1dd6813391c65664e982747602e", null ],
     [ "kvStore_Keys", "group__kv_group.html#ga6030fc2a672ae868f7603587245b9d5a", null ],
