@@ -3,7 +3,7 @@ var searchData=
   ['tags_0',['Tags',['../structjs_placement.html#af078a85b744b9ff3771bb2da6005b90d',1,'jsPlacement']]],
   ['tagslen_1',['TagsLen',['../structjs_placement.html#a35644f07531409518521b1b4fa28c9e3',1,'jsPlacement']]],
   ['template_2',['Template',['../structjs_stream_config.html#a50f866f0e73c4ff0a5f43b354a059fa9',1,'jsStreamConfig']]],
-  ['timeout_3',['Timeout',['../structkv_watch_options.html#a56183d56585697d058c7eeb20bdddb66',1,'kvWatchOptions']]],
+  ['timeout_3',['Timeout',['../structkv_watch_options.html#a56183d56585697d058c7eeb20bdddb66',1,'kvWatchOptions::Timeout()'],['../structkv_purge_options.html#a245c2def0f3aabe617219772cf7680a8',1,'kvPurgeOptions::Timeout()']]],
   ['timestamp_4',['Timestamp',['../structjs_msg_meta_data.html#abab9ed5600a3629ea6d6c78170d7d5e9',1,'jsMsgMetaData']]],
   ['total_5',['Total',['../structjs_a_p_i_stats.html#a1545170bebb347d0ea1254f51c3027cf',1,'jsAPIStats']]],
   ['ttl_6',['TTL',['../structkv_config.html#ad2f5503e2f2522cb52e0ba1b86983dba',1,'kvConfig']]],
