@@ -1,4 +1,4 @@
-// Copyright 2021 The NATS Authors
+// Copyright 2021-2022 The NATS Authors
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
 // You may obtain a copy of the License at
@@ -42,10 +42,9 @@ const int64_t    jsDefaultRequestWait    = 5000;
 const int64_t    jsDefaultStallWait      = 200;
 const char       *jsDigits               = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz";
 const int        jsBase                  = 62;
-const int64_t    jsOrderedHBInterval     = 5*(int64_t)1E9;
+const int64_t    jsOrderedHBInterval     = NATS_SECONDS_TO_NANOS(5);
 
 #define jsReplyTokenSize    (8)
-#define jsReplyPrefixLen    (NATS_INBOX_PRE_LEN + (jsReplyTokenSize) + 1)
 #define jsDefaultMaxMsgs    (512 * 1024)
 
 #define jsLastConsumerSeqHdr    "Nats-Last-Consumer"
@@ -257,6 +256,9 @@ natsConnection_JetStream(jsCtx **new_js, natsConnection *nc, jsOptions *opts)
     // we properly release the NATS connection.
     natsConn_retain(nc);
     js->nc = nc;
+    // This will be immutable and is computed based on the possible custom
+    // inbox prefix length (or the default "_INBOX.")
+    js->rpreLen = nc->inboxPfxLen+jsReplyTokenSize+1;
 
     s = natsMutex_Create(&(js->mu));
     if (s == NATS_OK)
@@ -368,6 +370,7 @@ js_setOpts(natsConnection **nc, bool *freePfx, jsCtx *js, jsOptions *opts, jsOpt
 
         // Stream info options
         resOpts->Stream.Info.DeletedDetails = (opts == NULL ? js->opts.Stream.Info.DeletedDetails : opts->Stream.Info.DeletedDetails);
+        resOpts->Stream.Info.SubjectsFilter = (opts == NULL ? js->opts.Stream.Info.SubjectsFilter : opts->Stream.Info.SubjectsFilter);
 
         *nc = js->nc;
         js_unlock(js);
@@ -536,28 +539,27 @@ _handleAsyncReply(natsConnection *nc, natsSubscription *sub, natsMsg *msg, void
 {
     const char      *subject    = natsMsg_GetSubject(msg);
     char            *id         = NULL;
-    jsCtx           *js         = NULL;
+    jsCtx           *js         = (jsCtx*) closure;
     natsMsg         *pmsg       = NULL;
     char            errTxt[256] = {'\0'};
     jsPubAckErr     pae;
     struct jsOptionsPublishAsync *opa = NULL;
 
-    if ((subject == NULL) || (int) strlen(subject) <= jsReplyPrefixLen)
+    if ((subject == NULL) || (int) strlen(subject) <= js->rpreLen)
     {
         natsMsg_Destroy(msg);
         return;
     }
 
-    id = (char*) (subject+jsReplyPrefixLen);
-    js = (jsCtx*) closure;
+    id = (char*) (subject+js->rpreLen);
 
     js_lock(js);
 
     pmsg = natsStrHash_Remove(js->pm, id);
     if (pmsg == NULL)
     {
-        natsMsg_Destroy(msg);
         js_unlock(js);
+        natsMsg_Destroy(msg);
         return;
     }
 
@@ -653,32 +655,38 @@ _newAsyncReply(char *reply, jsCtx *js)
         IFOK(s, natsStrHash_Create(&(js->pm), 64));
         if (s == NATS_OK)
         {
-            js->rpre = NATS_MALLOC(jsReplyPrefixLen+1);
+            js->rpre = NATS_MALLOC(js->rpreLen+1);
             if (js->rpre == NULL)
                 s = nats_setDefaultError(NATS_NO_MEMORY);
             else
             {
-                char tmp[NATS_INBOX_ARRAY_SIZE];
+                char nuid[NUID_BUFFER_LEN+1];
 
-                natsInbox_init(tmp, sizeof(tmp));
-                memcpy(js->rpre, tmp, NATS_INBOX_PRE_LEN);
-                memcpy(js->rpre+NATS_INBOX_PRE_LEN, tmp+((int)strlen(tmp)-jsReplyTokenSize), jsReplyTokenSize);
-                js->rpre[jsReplyPrefixLen-1] = '.';
-                js->rpre[jsReplyPrefixLen]   = '\0';
+                s = natsNUID_Next(nuid, sizeof(nuid));
+                if (s == NATS_OK)
+                {
+                    memcpy(js->rpre, js->nc->inboxPfx, js->nc->inboxPfxLen);
+                    memcpy(js->rpre+js->nc->inboxPfxLen, nuid+((int)strlen(nuid)-jsReplyTokenSize), jsReplyTokenSize);
+                    js->rpre[js->rpreLen-1] = '.';
+                    js->rpre[js->rpreLen]   = '\0';
+                }
             }
         }
         if (s == NATS_OK)
         {
-            char subj[jsReplyPrefixLen + 2];
+            char *subj = NULL;
 
-            snprintf(subj, sizeof(subj), "%s*", js->rpre);
-            s = natsConn_subscribeNoPool(&(js->rsub), js->nc, subj, _handleAsyncReply, (void*) js);
+            if (nats_asprintf(&subj, "%s*", js->rpre) < 0)
+                s = nats_setDefaultError(NATS_NO_MEMORY);
+            else
+                s = natsConn_subscribeNoPool(&(js->rsub), js->nc, subj, _handleAsyncReply, (void*) js);
             if (s == NATS_OK)
             {
                 _retain(js);
                 natsSubscription_SetPendingLimits(js->rsub, -1, -1);
                 natsSubscription_SetOnCompleteCB(js->rsub, _subComplete, (void*) js);
             }
+            NATS_FREE(subj);
         }
         if (s != NATS_OK)
         {
@@ -698,14 +706,14 @@ _newAsyncReply(char *reply, jsCtx *js)
         int64_t l;
         int     i;
 
-        memcpy(reply, js->rpre, jsReplyPrefixLen);
+        memcpy(reply, js->rpre, js->rpreLen);
         l = nats_Rand64();
         for (i=0; i < jsReplyTokenSize; i++)
         {
-            reply[jsReplyPrefixLen+i] = jsDigits[l%jsBase];
+            reply[js->rpreLen+i] = jsDigits[l%jsBase];
             l /= jsBase;
         }
-        reply[jsReplyPrefixLen+jsReplyTokenSize] = '\0';
+        reply[js->rpreLen+jsReplyTokenSize] = '\0';
     }
 
     return NATS_UPDATE_ERR_STACK(s);
@@ -726,7 +734,7 @@ _registerPubMsg(natsConnection **nc, char *reply, jsCtx *js, natsMsg *msg)
     js->pmcount++;
     s = _newAsyncReply(reply, js);
     if (s == NATS_OK)
-        id = reply+jsReplyPrefixLen;
+        id = reply+js->rpreLen;
     if ((s == NATS_OK)
             && (maxp > 0)
             && (js->pmcount > maxp))
@@ -780,11 +788,19 @@ js_PublishMsgAsync(jsCtx *js, natsMsg **msg, jsPubOptions *opts)
 {
     natsStatus      s   = NATS_OK;
     natsConnection  *nc = NULL;
-    char            reply[jsReplyPrefixLen + jsReplyTokenSize + 1];
+    char            replyBuf[32 + jsReplyTokenSize + 1];
+    char            *reply = replyBuf;
 
     if ((js == NULL) || (msg == NULL) || (*msg == NULL))
         return nats_setDefaultError(NATS_INVALID_ARG);
 
+    if (js->rpreLen > 32)
+    {
+        reply = NATS_MALLOC(js->rpreLen + jsReplyTokenSize + 1);
+        if (reply == NULL)
+            return nats_setDefaultError(NATS_NO_MEMORY);
+    }
+
     if (opts != NULL)
         s = _setHeadersFromOptions(*msg, opts);
 
@@ -795,7 +811,7 @@ js_PublishMsgAsync(jsCtx *js, natsMsg **msg, jsPubOptions *opts)
         s = natsConn_publish(nc, *msg, (const char*) reply, false);
         if (s != NATS_OK)
         {
-            char *id = reply+jsReplyPrefixLen;
+            char *id = reply+js->rpreLen;
 
             // The message may or may not have been sent, we don't know for sure.
             // We are going to attempt to remove from the map. If we can, then
@@ -819,6 +835,9 @@ js_PublishMsgAsync(jsCtx *js, natsMsg **msg, jsPubOptions *opts)
     if (s == NATS_OK)
         *msg = NULL;
 
+    if (reply != replyBuf)
+        NATS_FREE(reply);
+
     return NATS_UPDATE_ERR_STACK(s);
 }
 
@@ -1000,35 +1019,15 @@ static void
 _autoAckCB(natsConnection *nc, natsSubscription *sub, natsMsg *msg, void *closure)
 {
     jsSub   *jsi = (jsSub*) closure;
-    char    _reply[256];
-    char    *reply = NULL;
-    bool    frply  = false;
 
-    if (msg->reply != NULL)
-    {
-        if (strlen(msg->reply) < sizeof(_reply))
-        {
-            snprintf(_reply, sizeof(_reply), "%s", msg->reply);
-            reply = _reply;
-        }
-        else
-        {
-            reply = NATS_STRDUP(msg->reply);
-            frply = (reply != NULL ? true : false);
-        }
-    }
+    natsMsg_setNoDestroy(msg);
 
     // Invoke user callback
     (jsi->usrCb)(nc, sub, msg, jsi->usrCbClosure);
 
-    // Ack the message (unless we got a failure copying the reply subject)
-    if (reply == NULL)
-        return;
-
-    natsConnection_PublishString(nc, reply, jsAckAck);
-
-    if (frply)
-        NATS_FREE(reply);
+    natsMsg_Ack(msg, NULL);
+    natsMsg_clearNoDestroy(msg);
+    natsMsg_Destroy(msg);
 }
 
 natsStatus
@@ -1089,7 +1088,7 @@ jsSub_deleteConsumerAfterDrain(natsSubscription *sub)
         if (nc->opts->asyncErrCb != NULL)
         {
             char tmp[256];
-            snprintf(tmp, sizeof(tmp), "failed to delete consumer '%s': %d (%s)",
+            snprintf(tmp, sizeof(tmp), "failed to delete consumer '%s': %u (%s)",
                     consumer, s, natsStatus_GetText(s));
             natsAsyncCb_PostErrHandler(nc, sub, s, NATS_STRDUP(tmp));
         }
@@ -1366,6 +1365,36 @@ jsSub_processSequenceMismatch(natsSubscription *sub, natsMutex *mu, natsMsg *msg
     return NATS_UPDATE_ERR_STACK(s);
 }
 
+natsStatus
+natsSubscription_GetConsumerInfo(jsConsumerInfo **ci, natsSubscription *sub,
+                                 jsOptions *opts, jsErrCode *errCode)
+{
+    const char  *consumer = NULL;
+    const char  *stream   = NULL;
+    jsCtx       *js       = NULL;
+    natsStatus  s;
+
+    if ((ci == NULL) || (sub == NULL))
+        return nats_setDefaultError(NATS_INVALID_ARG);
+
+    natsSub_Lock(sub);
+    if ((sub->jsi == NULL) || (sub->jsi->consumer == NULL))
+    {
+        natsSub_Unlock(sub);
+        return nats_setDefaultError(NATS_INVALID_SUBSCRIPTION);
+    }
+    js = sub->jsi->js;
+    stream = (const char*) sub->jsi->stream;
+    consumer = (const char*) sub->jsi->consumer;
+    sub->refs++;
+    natsSub_Unlock(sub);
+
+    s = js_GetConsumerInfo(ci, js, stream, consumer, opts, errCode);
+
+    natsSub_release(sub);
+    return NATS_UPDATE_ERR_STACK(s);
+}
+
 natsStatus
 natsSubscription_GetSequenceMismatch(jsConsumerSequenceMismatch *csm, natsSubscription *sub)
 {
@@ -1425,15 +1454,13 @@ jsSub_scheduleFlowControlResponse(jsSub *jsi, const char *reply)
 }
 
 static natsStatus
-_checkMsg(natsMsg *msg, bool checkSts, bool *usrMsg, jsErrCode *jerr)
+_checkMsg(natsMsg *msg, bool checkSts, bool *usrMsg)
 {
     natsStatus  s    = NATS_OK;
     const char  *val = NULL;
     const char  *desc= NULL;
 
     *usrMsg = true;
-    if (jerr != NULL)
-        *jerr = 0;
 
     if ((msg->dataLen > 0) || (msg->hdrLen <= 0))
         return NATS_OK;
@@ -1457,12 +1484,9 @@ _checkMsg(natsMsg *msg, bool checkSts, bool *usrMsg, jsErrCode *jerr)
     if (strncmp(val, NOT_FOUND_STATUS, HDR_STATUS_LEN) == 0)
         return NATS_NOT_FOUND;
 
-    // Older servers may send a 408 when a request in the server was expired
-    // and interest is still found, which will be the case for our
-    // implementation. Regardless, ignore 408 errors, the caller will
-    // go back to wait for the next message.
+    // 408 indicating request timeout
     if (strncmp(val, REQ_TIMEOUT, HDR_STATUS_LEN) == 0)
-        return NATS_OK;
+        return NATS_TIMEOUT;
 
     // The possible 503 is handled directly in natsSub_nextMsg(), so we
     // would never get it here in this function.
@@ -1473,21 +1497,14 @@ _checkMsg(natsMsg *msg, bool checkSts, bool *usrMsg, jsErrCode *jerr)
 
 static natsStatus
 _sendPullRequest(natsConnection *nc, const char *subj, const char *rply,
-                 natsBuffer *buf, int batchSize, int64_t *timeout, int64_t start, bool noWait)
+                 natsBuffer *buf, int batchSize, int64_t timeout, bool noWait)
 {
     natsStatus  s;
     int64_t     expires;
 
-    *timeout -= (nats_Now()-start);
-    if (*timeout <= 0)
-    {
-        // At this point, consider that we have timed-out.
-        return nats_setDefaultError(NATS_TIMEOUT);
-    }
-
     // Make our request expiration a bit shorter than the
     // current timeout.
-    expires = (*timeout >= 20 ? *timeout - 10 : *timeout);
+    expires = (timeout >= 20 ? timeout - 10 : timeout);
 
     // Since "expires" is a Go time.Duration and our timeout
     // is in milliseconds, convert it to nanos.
@@ -1572,7 +1589,7 @@ natsSubscription_Fetch(natsMsgList *list, natsSubscription *sub, int batch, int6
         if (s == NATS_OK)
         {
             // Here we care only about user messages.
-            s = _checkMsg(msg, false, &usrMsg, errCode);
+            s = _checkMsg(msg, false, &usrMsg);
             if ((s == NATS_OK) && usrMsg)
                 msgs[count++] = msg;
             else
@@ -1584,20 +1601,31 @@ natsSubscription_Fetch(natsMsgList *list, natsSubscription *sub, int batch, int6
     // request to the server.
     if (((s == NATS_OK) || (s == NATS_TIMEOUT)) && (count != batch))
     {
+        bool sendReq  = true;
         bool doNoWait = (batch-count > 1 ? true : false);
 
-        s = _sendPullRequest(nc, subj, rply, &buf, batch-count,
-                             &timeout, start, doNoWait);
+        // Reset status in case we entered with timeout
+        s = NATS_OK;
+
         // Now wait for messages or a 404 saying that there are no more.
         while ((s == NATS_OK) && (count < batch))
         {
             natsMsg *msg    = NULL;
             bool    usrMsg  = false;
 
-            s = natsSub_nextMsg(&msg, sub, timeout, true);
+            timeout -= (nats_Now()-start);
+            if (timeout <= 0)
+                s = NATS_TIMEOUT;
+
+            if ((s == NATS_OK) && sendReq)
+            {
+                sendReq = false;
+                s = _sendPullRequest(nc, subj, rply, &buf, batch-count, timeout, doNoWait);
+            }
+            IFOK(s, natsSub_nextMsg(&msg, sub, timeout, true));
             if (s == NATS_OK)
             {
-                s = _checkMsg(msg, true, &usrMsg, errCode);
+                s = _checkMsg(msg, true, &usrMsg);
                 if ((s == NATS_OK) && usrMsg)
                     msgs[count++] = msg;
                 else
@@ -1608,10 +1636,15 @@ natsSubscription_Fetch(natsMsgList *list, natsSubscription *sub, int batch, int6
                     // wait this time.
                     if (doNoWait && (s == NATS_NOT_FOUND) && (count == 0))
                     {
+                        s        = NATS_OK;
                         doNoWait = false;
-
-                        s = _sendPullRequest(nc, subj, rply, &buf, batch-count,
-                                             &timeout, start, false);
+                        sendReq  = true;
+                    }
+                    else if ((s == NATS_TIMEOUT) && (count == 0))
+                    {
+                        // If we get a 408, we will bail if we already collected some
+                        // messages, otherwise ignore and go back calling nextMsg.
+                        s = NATS_OK;
                     }
                 }
             }
@@ -1879,7 +1912,8 @@ _subscribe(natsSubscription **new_sub, jsCtx *js, const char *subject, const cha
     natsSubscription    *sub        = NULL;
     natsMsgHandler      cb          = NULL;
     void                *cbClosure  = NULL;
-    char                inbox[NATS_INBOX_ARRAY_SIZE];
+    natsInbox           *inbox      = NULL;
+    int64_t             maxap       = 0;
     jsOptions           jo;
     jsSubOptions        o;
     jsConsumerConfig    cfgStack;
@@ -1899,6 +1933,11 @@ _subscribe(natsSubscription **new_sub, jsCtx *js, const char *subject, const cha
         jsSubOptions_Init(&o);
         opts = &o;
     }
+    if (opts->Config.InactiveThreshold < 0)
+        return nats_setError(NATS_INVALID_ARG,
+                             "invalid InactiveThreshold value (%d), needs to be greater or equal to 0",
+                             (int) opts->Config.InactiveThreshold);
+
     // If user configures optional start sequence or time, the deliver policy
     // need to be updated accordingly. Server will return error if user tries to have both set.
     if (opts->Config.OptStartSeq > 0)
@@ -2000,6 +2039,7 @@ PROCESS_INFO:
 
         // Capture the HB interval (convert in millsecond since Go duration is in nanos)
         hbi = info->Config->Heartbeat / 1000000;
+        maxap = info->Config->MaxAckPending;
     }
     else if (((s != NATS_OK) && (s != NATS_NOT_FOUND)) || ((s == NATS_NOT_FOUND) && consBound))
     {
@@ -2021,7 +2061,7 @@ PROCESS_INFO:
         if (!isPullMode)
         {
             // Attempt to create consumer if not found nor binding.
-            natsInbox_init(inbox, sizeof(inbox));
+            natsConn_newInbox(nc, &inbox);
             deliver = (const char*) inbox;
             cfg->DeliverSubject = deliver;
         }
@@ -2034,7 +2074,7 @@ PROCESS_INFO:
             cfg->FlowControl = true;
             cfg->AckPolicy   = js_AckNone;
             cfg->MaxDeliver  = 1;
-            cfg->AckWait     = (24*60*60)*(int64_t)1E9; // Just set to something known, not utilized.
+            cfg->AckWait     = NATS_SECONDS_TO_NANOS(24*60*60); // Just set to something known, not utilized.
             if (opts->Config.Heartbeat <= 0)
                 cfg->Heartbeat = jsOrderedHBInterval;
         }
@@ -2046,11 +2086,6 @@ PROCESS_INFO:
 
             // Set DeliverGroup to queue name, possibly NULL
             cfg->DeliverGroup = opts->Queue;
-
-            // If we have acks at all and the MaxAckPending is not set go ahead
-            // and set to the internal max.
-            if ((cfg->MaxAckPending == 0) && (cfg->AckPolicy != js_AckNone))
-                cfg->MaxAckPending = NATS_OPTS_DEFAULT_MAX_PENDING_MSGS;
         }
 
         // Capture the HB interval (convert in millsecond since Go duration is in nanos)
@@ -2080,9 +2115,10 @@ PROCESS_INFO:
                 jsi->pull   = isPullMode;
                 jsi->ordered= opts->Ordered;
                 jsi->dseq   = 1;
+                jsi->ackNone= (opts->Config.AckPolicy == js_AckNone || opts->Ordered);
                 js_retain(js);
 
-                if ((usrCB != NULL) && !opts->ManualAck && (opts->Config.AckPolicy != js_AckNone))
+                if ((usrCB != NULL) && !opts->ManualAck && !jsi->ackNone)
                 {
                     // Keep track of user provided CB and closure
                     jsi->usrCb          = usrCB;
@@ -2103,7 +2139,7 @@ PROCESS_INFO:
     {
         if (isPullMode)
         {
-            s = natsInbox_init(inbox, sizeof(inbox));
+            s = natsConn_newInbox(nc, &inbox);
             deliver = (const char*) inbox;
         }
         // Create the NATS subscription on given deliver subject. Note that
@@ -2161,8 +2197,10 @@ PROCESS_INFO:
         }
         else
         {
+            maxap = info->Config->MaxAckPending;
             natsSub_Lock(sub);
             jsi->dc = true;
+            jsi->pending = info->NumPending + info->Delivered.Consumer;
             // There may be a race in the case of an ordered consumer where by this
             // time, the consumer has been recreated (jsResetOrderedConsumer). So
             // set only if jsi->consumer is NULL!
@@ -2175,6 +2213,21 @@ PROCESS_INFO:
 END:
     if (s == NATS_OK)
     {
+        int64_t ml = 0;
+        int64_t bl = 0;
+
+        natsSub_Lock(sub);
+        ml = (int64_t) sub->msgsLimit;
+        bl = (int64_t) sub->bytesLimit;
+        natsSub_Unlock(sub);
+        if (maxap > ml)
+        {
+            ml = maxap;
+            if (maxap*1024*1024 > bl)
+                bl = maxap*1024*1024;
+
+            natsSubscription_SetPendingLimits(sub, (int) ml, (int) bl);
+        }
         *new_sub = sub;
     }
     else
@@ -2194,6 +2247,7 @@ END:
         NATS_FREE((char*) jo.Prefix);
     if (freeStream)
         NATS_FREE((char*) stream);
+    natsInbox_Destroy(inbox);
 
     return NATS_UPDATE_ERR_STACK(s);
 }
@@ -2257,14 +2311,27 @@ js_PullSubscribe(natsSubscription **sub, jsCtx *js, const char *subject, const c
     return NATS_UPDATE_ERR_STACK(s);
 }
 
+typedef struct __ackOpts
+{
+    const char  *ackType;
+    bool        inProgress;
+    bool        sync;
+    int64_t     nakDelay;
+
+} _ackOpts;
+
 static natsStatus
-_ackMsg(natsMsg *msg, jsOptions *opts, const char *ackType, bool inProgress, bool sync, jsErrCode *errCode)
+_ackMsg(natsMsg *msg, jsOptions *opts, _ackOpts *o, jsErrCode *errCode)
 {
     natsSubscription    *sub = NULL;
     natsConnection      *nc  = NULL;
     jsCtx               *js  = NULL;
     jsSub               *jsi = NULL;
     natsStatus          s    = NATS_OK;
+    const char          *body= o->ackType;
+    bool                sync = o->sync;
+    int64_t             wait = 0;
+    char                tmp[64];
 
     if (msg == NULL)
         return nats_setDefaultError(NATS_INVALID_ARG);
@@ -2284,10 +2351,21 @@ _ackMsg(natsMsg *msg, jsOptions *opts, const char *ackType, bool inProgress, boo
     js = jsi->js;
     nc = sub->conn;
 
+    // If option with Wait is specified, transform all Acks as sync operation.
+    if ((opts != NULL) && (opts->Wait > 0))
+    {
+        wait = opts->Wait;
+        sync = true;
+    }
+    if (o->nakDelay > 0)
+    {
+        int64_t v = NATS_MILLIS_TO_NANOS(o->nakDelay);
+        snprintf(tmp, sizeof(tmp), "%s {\"delay\":%" PRId64 "}", o->ackType, v);
+        body = (const char*) tmp;
+    }
     if (sync)
     {
         natsMsg *rply   = NULL;
-        int64_t wait    = (opts != NULL ? opts->Wait : 0);
 
         if (wait == 0)
         {
@@ -2297,15 +2375,15 @@ _ackMsg(natsMsg *msg, jsOptions *opts, const char *ackType, bool inProgress, boo
             wait = js->opts.Wait;
             js_unlock(js);
         }
-        IFOK_JSR(s, natsConnection_RequestString(&rply, nc, msg->reply, ackType, wait));
+        IFOK_JSR(s, natsConnection_RequestString(&rply, nc, msg->reply, body, wait));
         natsMsg_Destroy(rply);
     }
     else
     {
-        s = natsConnection_PublishString(nc, msg->reply, ackType);
+        s = natsConnection_PublishString(nc, msg->reply, body);
     }
     // Indicate that we have ack'ed the message
-    if ((s == NATS_OK) && !inProgress)
+    if ((s == NATS_OK) && !o->inProgress)
         natsMsg_setAcked(msg);
 
     return NATS_UPDATE_ERR_STACK(s);
@@ -2314,31 +2392,61 @@ _ackMsg(natsMsg *msg, jsOptions *opts, const char *ackType, bool inProgress, boo
 natsStatus
 natsMsg_Ack(natsMsg *msg, jsOptions *opts)
 {
-    return _ackMsg(msg, opts, jsAckAck, false, false, NULL);
+    natsStatus  s;
+    _ackOpts    o = {jsAckAck, false, false, 0};
+
+    s = _ackMsg(msg, opts, &o, NULL);
+    return NATS_UPDATE_ERR_STACK(s);
 }
 
 natsStatus
 natsMsg_AckSync(natsMsg *msg, jsOptions *opts, jsErrCode *errCode)
 {
-    return _ackMsg(msg, opts, jsAckAck, false, true, errCode);
+    natsStatus  s;
+    _ackOpts    o = {jsAckAck, false, true, 0};
+
+    s = _ackMsg(msg, opts, &o, errCode);
+    return NATS_UPDATE_ERR_STACK(s);
 }
 
 natsStatus
 natsMsg_Nak(natsMsg *msg, jsOptions *opts)
 {
-    return _ackMsg(msg, opts, jsAckNak, false, false, NULL);
+    natsStatus  s;
+    _ackOpts    o = {jsAckNak, false, false, 0};
+
+    s = _ackMsg(msg, opts, &o, NULL);
+    return NATS_UPDATE_ERR_STACK(s);
+}
+
+natsStatus
+natsMsg_NakWithDelay(natsMsg *msg, int64_t delay, jsOptions *opts)
+{
+    natsStatus  s;
+    _ackOpts    o = {jsAckNak, false, false, delay};
+
+    s = _ackMsg(msg, opts, &o, NULL);
+    return NATS_UPDATE_ERR_STACK(s);
 }
 
 natsStatus
 natsMsg_InProgress(natsMsg *msg, jsOptions *opts)
 {
-    return _ackMsg(msg, opts, jsAckInProgress, true, false, NULL);
+    natsStatus  s;
+    _ackOpts    o = {jsAckInProgress, true, false, 0};
+
+    s = _ackMsg(msg, opts, &o, NULL);
+    return NATS_UPDATE_ERR_STACK(s);
 }
 
 natsStatus
 natsMsg_Term(natsMsg *msg, jsOptions *opts)
 {
-    return _ackMsg(msg, opts, jsAckTerm, false, false, NULL);
+    natsStatus  s;
+    _ackOpts    o = {jsAckTerm, false, false, 0};
+
+    s = _ackMsg(msg, opts, &o, NULL);
+    return NATS_UPDATE_ERR_STACK(s);
 }
 
 natsStatus
@@ -2509,7 +2617,7 @@ _recreateOrderedCons(void *closure)
         cc.FlowControl      = true;
         cc.AckPolicy        = js_AckNone;
         cc.MaxDeliver       = 1;
-        cc.AckWait          = (24*60*60)*(int64_t)1E9; // Just set to something known, not utilized.
+        cc.AckWait          = NATS_SECONDS_TO_NANOS(24*60*60); // Just set to something known, not utilized.
         cc.Heartbeat        = jsi->hbi * 1000000;
         cc.DeliverSubject   = sub->subject;
         cc.DeliverPolicy    = js_DeliverByStartSequence;
@@ -2534,7 +2642,7 @@ _recreateOrderedCons(void *closure)
         if (nc->opts->asyncErrCb != NULL)
         {
             char tmp[256];
-            snprintf(tmp, sizeof(tmp), "failed recreating ordered consumer: %d (%s)",
+            snprintf(tmp, sizeof(tmp), "failed recreating ordered consumer: %u (%s)",
                      s, natsStatus_GetText(s));
             natsAsyncCb_PostErrHandler(nc, sub, s, NATS_STRDUP(tmp));
         }
@@ -2579,7 +2687,7 @@ jsSub_resetOrderedConsumer(natsSubscription *sub, natsMutex *mu, uint64_t sseq)
     }
 
     // Grab new inbox.
-    s = natsInbox_Create(&newDeliver);
+    s = natsConn_newInbox(nc, &newDeliver);
     if (s != NATS_OK)
         return NATS_UPDATE_ERR_STACK(s);
 
