@@ -1,4 +1,4 @@
-// Copyright 2021 The NATS Authors
+// Copyright 2021-2022 The NATS Authors
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
 // You may obtain a copy of the License at
@@ -18,11 +18,12 @@
 #include "mem.h"
 #include "util.h"
 #include "js.h"
+#include "conn.h"
+#include "sub.h"
 
 static const char *kvBucketNameTmpl  = "KV_%s";
 static const char *kvSubjectsTmpl    = "$KV.%s.>";
 static const char *kvSubjectsPreTmpl = "$KV.%s.";
-// static const char *kvNoPending       = "0";
 
 #define KV_WATCH_FOR_EVER (int64_t)(0x7FFFFFFFFFFFFFFF)
 
@@ -30,10 +31,18 @@ static const char *kvSubjectsPreTmpl = "$KV.%s.";
 char        buffer[128];    \
 natsBuffer  buf;
 
-#define BUILD_SUBJECT \
-natsBuf_InitWithBackend(&buf, buffer, 0, sizeof(buffer));   \
-s = natsBuf_Append(&buf, kv->pre, -1);                      \
-IFOK(s, natsBuf_Append(&buf, key, -1));                     \
+#define USE_JS_PREFIX   true
+#define KEY_NAME_ONLY   false
+
+#define BUILD_SUBJECT(p) \
+s = natsBuf_InitWithBackend(&buf, buffer, 0, sizeof(buffer)); \
+if ((p) && kv->useJSPrefix) \
+{ \
+    IFOK(s, natsBuf_Append(&buf, kv->js->opts.Prefix, -1)); \
+    IFOK(s, natsBuf_AppendByte(&buf, '.')); \
+} \
+IFOK(s, natsBuf_Append(&buf, kv->pre, -1)); \
+IFOK(s, natsBuf_Append(&buf, key, -1)); \
 IFOK(s, natsBuf_AppendByte(&buf, 0));
 
 #define KV_DEFINE_LIST \
@@ -168,6 +177,7 @@ _createKV(kvStore **new_kv, jsCtx *js, const char *bucket)
 
     if (s == NATS_OK)
     {
+        kv->useJSPrefix = (strcmp(js->opts.Prefix, jsDefaultAPIPrefix) != 0 ? true : false);
         kv->js = js;
         js_retain(js);
         *new_kv = kv;
@@ -178,6 +188,54 @@ _createKV(kvStore **new_kv, jsCtx *js, const char *bucket)
     return NATS_UPDATE_ERR_STACK(s);
 }
 
+static bool
+_sameStrings(const char *s1, const char *s2)
+{
+    bool s1Empty = nats_IsStringEmpty(s1);
+    bool s2Empty = nats_IsStringEmpty(s2);
+
+    // Same if both empty.
+    if (s1Empty && s2Empty)
+        return true;
+
+    // Not same if one is empty while other is not.
+    if ((s1Empty && !s2Empty) || (!s1Empty && s2Empty))
+        return false;
+
+    // Return result of comparison of s1 and s2
+    return (strcmp(s1, s2) == 0 ? true : false);
+}
+
+static bool
+_sameStreamCfg(jsStreamConfig *oc, jsStreamConfig *nc)
+{
+    // Check some of the stream's configuration properties only,
+    // the ones that we set when creating a KV stream.
+    if (!_sameStrings(oc->Description, nc->Description))
+        return false;
+    if (oc->SubjectsLen != nc->SubjectsLen)
+        return false;
+    if (!_sameStrings(oc->Subjects[0], nc->Subjects[0]))
+        return false;
+    if (oc->MaxMsgsPerSubject != nc->MaxMsgsPerSubject)
+        return false;
+    if (oc->MaxBytes != nc->MaxBytes)
+        return false;
+    if (oc->MaxAge != nc->MaxAge)
+        return false;
+    if (oc->MaxMsgSize != nc->MaxMsgSize)
+        return false;
+    if (oc->Storage != nc->Storage)
+        return false;
+    if (oc->Replicas != nc->Replicas)
+        return false;
+    if (oc->AllowRollup != nc->AllowRollup)
+        return false;
+    if (oc->DenyDelete != nc->DenyDelete)
+        return false;
+    return true;
+}
+
 natsStatus
 js_CreateKeyValue(kvStore **new_kv, jsCtx *js, kvConfig *cfg)
 {
@@ -212,21 +270,46 @@ js_CreateKeyValue(kvStore **new_kv, jsCtx *js, kvConfig *cfg)
     }
     if (s == NATS_OK)
     {
+        int64_t     maxBytes    = (cfg->MaxBytes == 0 ? -1 : cfg->MaxBytes);
+        int32_t     maxMsgSize  = (cfg->MaxValueSize == 0 ? -1 : cfg->MaxValueSize);
+        jsErrCode   jerr        = 0;
+
         jsStreamConfig_Init(&sc);
         sc.Name = kv->stream;
         sc.Description = cfg->Description;
         sc.Subjects = (const char*[1]){subject};
         sc.SubjectsLen = 1;
         sc.MaxMsgsPerSubject = history;
-        sc.MaxBytes = cfg->MaxBytes;
+        sc.MaxBytes = maxBytes;
         sc.MaxAge = cfg->TTL;
-        sc.MaxMsgSize = cfg->MaxValueSize;
+        sc.MaxMsgSize = maxMsgSize;
         sc.Storage = cfg->StorageType;
         sc.Replicas = replicas;
         sc.AllowRollup = true;
         sc.DenyDelete = true;
 
-        s = js_AddStream(NULL, js, &sc, NULL, NULL);
+        // If connecting to a v2.7.2+, create with discard new policy
+        if (natsConn_srvVersionAtLeast(kv->js->nc, 2, 7, 2))
+            sc.Discard = js_DiscardNew;
+
+        s = js_AddStream(NULL, js, &sc, NULL, &jerr);
+        if ((s != NATS_OK) && (jerr == JSStreamNameExistErr))
+        {
+            jsStreamInfo *si = NULL;
+
+            nats_clearLastError();
+            s = js_GetStreamInfo(&si, js, sc.Name, NULL, NULL);
+            if (s == NATS_OK)
+            {
+                si->Config->Discard = sc.Discard;
+                if (_sameStreamCfg(si->Config, &sc))
+                    s = js_UpdateStream(NULL, js, &sc, NULL, NULL);
+                else
+                    s = nats_setError(NATS_ERR, "%s",
+                        "Existing configuration is different");
+            }
+            jsStreamInfo_Destroy(si);
+        }
     }
     if (s == NATS_OK)
         *new_kv = kv;
@@ -331,8 +414,7 @@ validKey(const char *key)
 static natsStatus
 _createEntry(kvEntry **new_entry, kvStore *kv, natsMsg **msg)
 {
-    kvEntry     *e   = NULL;
-    const char  *val = NULL;
+    kvEntry *e = NULL;
 
     e = (kvEntry*) NATS_CALLOC(1, sizeof(kvEntry));
     if (e == NULL)
@@ -342,14 +424,7 @@ _createEntry(kvEntry **new_entry, kvStore *kv, natsMsg **msg)
     e->kv  = kv;
     e->msg = *msg;
     e->key = e->msg->subject+(int)strlen(kv->pre);
-
-    if (natsMsgHeader_Get(e->msg, kvOpHeader, &val) == NATS_OK)
-    {
-        if (strcmp(val, kvOpDeleteStr) == 0)
-            e->op = kvOp_Delete;
-        else if (strcmp(val, kvOpPurgeStr) == 0)
-            e->op = kvOp_Purge;
-    }
+    e->op  = kvOp_Put;
 
     // Indicate that we took ownership of the message
     *msg = NULL;
@@ -358,8 +433,24 @@ _createEntry(kvEntry **new_entry, kvStore *kv, natsMsg **msg)
     return NATS_OK;
 }
 
+static kvOperation
+_getKVOp(natsMsg *msg)
+{
+    const char  *val = NULL;
+    kvOperation op   = kvOp_Put;
+
+    if (natsMsgHeader_Get(msg, kvOpHeader, &val) == NATS_OK)
+    {
+        if (strcmp(val, kvOpDeleteStr) == 0)
+            op = kvOp_Delete;
+        else if (strcmp(val, kvOpPurgeStr) == 0)
+            op = kvOp_Purge;
+    }
+    return op;
+}
+
 static natsStatus
-_getEntry(kvEntry **new_entry, bool *deleted, kvStore *kv, const char *key)
+_getEntry(kvEntry **new_entry, bool *deleted, kvStore *kv, const char *key, uint64_t revision)
 {
     natsStatus  s       = NATS_OK;
     natsMsg     *msg    = NULL;
@@ -372,9 +463,19 @@ _getEntry(kvEntry **new_entry, bool *deleted, kvStore *kv, const char *key)
     if (!validKey(key))
         return nats_setError(NATS_INVALID_ARG, "%s", kvErrInvalidKey);
 
-    BUILD_SUBJECT;
-    IFOK(s, js_GetLastMsg(&msg, kv->js, kv->stream, natsBuf_Data(&buf), NULL, NULL));
+    BUILD_SUBJECT(KEY_NAME_ONLY);
+    if (revision == 0)
+    {
+        IFOK(s, js_GetLastMsg(&msg, kv->js, kv->stream, natsBuf_Data(&buf), NULL, NULL));
+    }
+    else
+    {
+        IFOK(s, js_GetMsg(&msg, kv->js, kv->stream, revision, NULL, NULL));
+        IFOK(s, (strcmp(natsMsg_GetSubject(msg), natsBuf_Data(&buf)) == 0 ? NATS_OK : NATS_NOT_FOUND));
+    }
     IFOK(s, _createEntry(&e, kv, &msg));
+    if (s == NATS_OK)
+        e->op = _getKVOp(e->msg);
 
     natsBuf_Cleanup(&buf);
     natsMsg_Destroy(msg);
@@ -399,7 +500,7 @@ _getEntry(kvEntry **new_entry, bool *deleted, kvStore *kv, const char *key)
 }
 
 natsStatus
-kvStore_Get(kvEntry **new_entry, kvStore *kv, const char *key)
+_get(kvEntry **new_entry, kvStore *kv, const char *key, uint64_t revision)
 {
     natsStatus  s;
     bool        deleted = false;
@@ -407,7 +508,7 @@ kvStore_Get(kvEntry **new_entry, kvStore *kv, const char *key)
     if ((new_entry == NULL) || (kv == NULL))
         return nats_setDefaultError(NATS_INVALID_ARG);
 
-    s = _getEntry(new_entry, &deleted, kv, key);
+    s = _getEntry(new_entry, &deleted, kv, key, revision);
     if (s == NATS_OK)
     {
         if (deleted)
@@ -423,6 +524,31 @@ kvStore_Get(kvEntry **new_entry, kvStore *kv, const char *key)
     return NATS_UPDATE_ERR_STACK(s);
 }
 
+natsStatus
+kvStore_Get(kvEntry **new_entry, kvStore *kv, const char *key)
+{
+    natsStatus s = _get(new_entry, kv, key, 0);
+    // We don't want stack trace for this error
+    if (s == NATS_NOT_FOUND)
+        return s;
+    return NATS_UPDATE_ERR_STACK(s);
+}
+
+natsStatus
+kvStore_GetRevision(kvEntry **new_entry, kvStore *kv, const char *key, uint64_t revision)
+{
+    natsStatus s;
+
+    if (revision <= 0)
+        return nats_setError(NATS_INVALID_ARG, "%s", kvErrInvalidRevision);
+
+    s = _get(new_entry, kv, key, revision);
+    // We don't want stack trace for this error
+    if (s == NATS_NOT_FOUND)
+        return s;
+    return NATS_UPDATE_ERR_STACK(s);
+}
+
 static natsStatus
 _putEntry(uint64_t *rev, kvStore *kv, jsPubOptions *po, const char *key, const void *data, int len)
 {
@@ -443,7 +569,7 @@ _putEntry(uint64_t *rev, kvStore *kv, jsPubOptions *po, const char *key, const v
     if (!validKey(key))
         return nats_setError(NATS_INVALID_ARG, "%s", kvErrInvalidKey);
 
-    BUILD_SUBJECT;
+    BUILD_SUBJECT(USE_JS_PREFIX);
     IFOK(s, js_Publish(ppa, kv->js, natsBuf_Data(&buf), data, len, po, NULL));
 
     if ((s == NATS_OK) && (rev != NULL))
@@ -491,7 +617,7 @@ kvStore_Create(uint64_t *rev, kvStore *kv, const char *key, const void *data, in
 
     // Since we have tombstones for DEL ops for watchers, this could be from that
     // so we need to double check.
-    ls = _getEntry(&e, &deleted, kv, key);
+    ls = _getEntry(&e, &deleted, kv, key, 0);
     if (ls == NATS_OK)
     {
         if (deleted)
@@ -532,10 +658,12 @@ kvStore_UpdateString(uint64_t *rev, kvStore *kv, const char *key, const char *da
 }
 
 static natsStatus
-_delete(kvStore *kv, const char *key, bool purge)
+_delete(kvStore *kv, const char *key, bool purge, kvPurgeOptions *opts)
 {
-    natsStatus  s;
-    natsMsg     *msg = NULL;
+    natsStatus      s;
+    natsMsg         *msg = NULL;
+    jsPubOptions    o;
+    jsPubOptions    *po = NULL;
     DEFINE_BUF_FOR_SUBJECT;
 
     if (kv == NULL)
@@ -544,7 +672,7 @@ _delete(kvStore *kv, const char *key, bool purge)
     if (!validKey(key))
         return nats_setError(NATS_INVALID_ARG, "%s", kvErrInvalidKey);
 
-    BUILD_SUBJECT;
+    BUILD_SUBJECT(USE_JS_PREFIX);
     IFOK(s, natsMsg_Create(&msg, natsBuf_Data(&buf), NULL, NULL, 0));
     if (s == NATS_OK)
     {
@@ -558,7 +686,13 @@ _delete(kvStore *kv, const char *key, bool purge)
             s = natsMsgHeader_Set(msg, kvOpHeader, kvOpDeleteStr);
         }
     }
-    IFOK(s, js_PublishMsg(NULL, kv->js, msg, NULL, NULL));
+    if (purge && (opts != NULL) && (opts->Timeout > 0))
+    {
+        jsPubOptions_Init(&o);
+        o.MaxWait = opts->Timeout;
+        po = &o;
+    }
+    IFOK(s, js_PublishMsg(NULL, kv->js, msg, po, NULL));
 
     natsBuf_Cleanup(&buf);
     natsMsg_Destroy(msg);
@@ -568,19 +702,29 @@ _delete(kvStore *kv, const char *key, bool purge)
 natsStatus
 kvStore_Delete(kvStore *kv, const char *key)
 {
-    natsStatus s = _delete(kv, key, false);
+    natsStatus s = _delete(kv, key, false, NULL);
     return NATS_UPDATE_ERR_STACK(s);
 }
 
 natsStatus
-kvStore_Purge(kvStore *kv, const char *key)
+kvStore_Purge(kvStore *kv, const char *key, kvPurgeOptions *opts)
 {
-    natsStatus s = _delete(kv, key, true);
+    natsStatus s = _delete(kv, key, true, opts);
     return NATS_UPDATE_ERR_STACK(s);
 }
 
 natsStatus
-kvStore_PurgeDeletes(kvStore *kv, kvWatchOptions *opts)
+kvPurgeOptions_Init(kvPurgeOptions *opts)
+{
+    if (opts == NULL)
+        return nats_setDefaultError(NATS_INVALID_ARG);
+
+    memset(opts, 0, sizeof(kvPurgeOptions));
+    return NATS_OK;
+}
+
+natsStatus
+kvStore_PurgeDeletes(kvStore *kv, kvPurgeOptions *opts)
 {
     natsStatus      s;
     kvWatcher       *w = NULL;
@@ -589,8 +733,16 @@ kvStore_PurgeDeletes(kvStore *kv, kvWatchOptions *opts)
     kvEntry         *t = NULL;
     natsBuffer      buf;
     char            buffer[128];
+    kvWatchOptions  wo;
+    kvWatchOptions  *wpo = NULL;
 
-    s = kvStore_WatchAll(&w, kv, opts);
+    if ((opts != NULL) && (opts->Timeout > 0))
+    {
+        kvWatchOptions_Init(&wo);
+        wo.Timeout = opts->Timeout;
+        wpo = &wo;
+    }
+    s = kvStore_WatchAll(&w, kv, wpo);
     if (s != NATS_OK)
         return NATS_UPDATE_ERR_STACK(s);
 
@@ -613,12 +765,23 @@ kvStore_PurgeDeletes(kvStore *kv, kvWatchOptions *opts)
     }
     if ((s == NATS_OK) && (h != NULL))
     {
-        jsOptions po;
+        jsOptions   po;
+        int64_t     olderThan = (opts != NULL ? opts->DeleteMarkersOlderThan : 0);
+        int64_t     limit = 0;
+
+        // Negative value is used to instruct to always remove markers, regardless
+        // of age. If set to 0 (or not set), use our default value.
+        if (olderThan == 0)
+            olderThan = NATS_SECONDS_TO_NANOS(30*60); // 30 minutes
+        else if (olderThan > 0)
+            limit = nats_NowInNanoSeconds() - olderThan;
 
         jsOptions_Init(&po);
 
         natsBuf_InitWithBackend(&buf, buffer, 0, sizeof(buffer));
 
+        // Go over the list, even when s != NATS_OK so we destroy
+        // each entry and don't have a memory leak.
         for (; h != NULL; )
         {
             natsBuf_Reset(&buf);
@@ -628,6 +791,12 @@ kvStore_PurgeDeletes(kvStore *kv, kvWatchOptions *opts)
             if (s == NATS_OK)
             {
                 po.Stream.Purge.Subject = (const char*) natsBuf_Data(&buf);
+                po.Stream.Purge.Keep = 0;
+                if ((olderThan > 0) && (kvEntry_Created(h) >= limit))
+                {
+                    // Keep this marker since it is more recent than the threshold.
+                    po.Stream.Purge.Keep = 1;
+                }
                 s = js_PurgeStream(kv->js, kv->stream, &po, NULL);
             }
             e = h;
@@ -706,6 +875,7 @@ GET_NEXT:
     {
         natsMsg     *msg = NULL;
         uint64_t    delta= 0;
+        bool        next = false;
 
         w->refs++;
         natsMutex_Unlock(w->mu);
@@ -732,29 +902,47 @@ GET_NEXT:
         IFOK(s, js_getMetaData(msg->reply+jsAckPrefixLen,
                                NULL, NULL, NULL, NULL, &(msg->seq),
                                NULL, &(msg->time), &delta, 3));
-        IFOK(s, _createEntry(&e, w->kv, &msg));
         if (s == NATS_OK)
         {
-            e->delta = delta;
+            kvOperation op = _getKVOp(msg);
 
-            // Check if done with initial values
-            if (!w->initDone && (delta == 0))
+            if (!w->ignoreDel || (op != kvOp_Delete && op != kvOp_Purge))
             {
-                w->initDone = true;
-                w->retMarker = true;
+                s = _createEntry(&e, w->kv, &msg);
+                if (s == NATS_OK)
+                {
+                    e->op    = op;
+                    e->delta = delta;
+                }
             }
-            if (w->ignoreDel && ((e->op == kvOp_Delete) || e->op == kvOp_Purge))
+            else
             {
-                kvEntry_Destroy(e);
-                e = NULL;
                 timeout -= (nats_Now() - start);
                 if (timeout > 0)
-                    goto GET_NEXT;
+                    next = true;
                 else
                     s = nats_setDefaultError(NATS_TIMEOUT);
             }
+            // Here, regardless of status, need to update this
+            if (!w->initDone)
+            {
+                w->received++;
+                // We set this on the first trip through..
+                if (w->initPending == 0)
+                    w->initPending = delta;
+                if ((w->received > w->initPending) || (delta == 0))
+                {
+                    w->initDone  = true;
+                    w->retMarker = true;
+                }
+            }
         }
+        // The `msg` variable may be NULL if an entry was created
+        // and took ownership. It is ok since then destroy will be a no-op.
         natsMsg_Destroy(msg);
+
+        if (next)
+            goto GET_NEXT;
     }
     natsMutex_Unlock(w->mu);
 
@@ -792,30 +980,12 @@ kvStore_Watch(kvWatcher **new_watcher, kvStore *kv, const char *key, kvWatchOpti
     w->kv = kv;
     w->refs = 1;
 
-    BUILD_SUBJECT;
+    BUILD_SUBJECT(KEY_NAME_ONLY);
     IFOK(s, natsMutex_Create(&(w->mu)));
     if (s == NATS_OK)
     {
-        natsStatus  ls;
-        natsMsg     *msg = NULL;
+        // Use ordered consumer to deliver results
 
-        // Check if we have anything pending.
-        ls = js_GetLastMsg(&msg, kv->js, kv->stream, natsBuf_Data(&buf), NULL, NULL);
-        if (ls == NATS_OK)
-            natsMsg_Destroy(msg);
-        else
-        {
-            nats_clearLastError();
-            if (ls == NATS_NOT_FOUND)
-            {
-                w->initDone  = true;
-                w->retMarker = true;
-            }
-        }
-    }
-    // Use ordered consumer to deliver results
-    if (s == NATS_OK)
-    {
         jsSubOptions_Init(&so);
         so.Ordered = true;
         if ((opts == NULL) || !opts->IncludeHistory)
@@ -828,6 +998,18 @@ kvStore_Watch(kvWatcher **new_watcher, kvStore *kv, const char *key, kvWatchOpti
                 w->ignoreDel = true;
         }
         s = js_SubscribeSync(&(w->sub), kv->js, natsBuf_Data(&buf), NULL, &so, NULL);
+        if (s == NATS_OK)
+        {
+            natsSubscription *sub = w->sub;
+
+            natsSub_Lock(sub);
+            if ((sub->jsi != NULL) && (sub->jsi->pending == 0))
+            {
+                w->initDone = true;
+                w->retMarker = true;
+            }
+            natsSub_Unlock(sub);
+        }
     }
 
     natsBuf_Cleanup(&buf);
@@ -984,6 +1166,12 @@ kvStore_History(kvEntryList *list, kvStore *kv, const char *key, kvWatchOptions
         else
             kvEntry_Destroy(e);
     }
+    // Go client returns "not found" if the subject exists, but
+    // there is nothing to return, so basically after a purge deletes,
+    // a key has no data and no marker, and we return "not found".
+    if ((s == NATS_OK) && (list->Count == 0))
+        return NATS_NOT_FOUND;
+
     return NATS_UPDATE_ERR_STACK(s);
 }
 
