@@ -1,4 +1,4 @@
-// Copyright 2015-2021 The NATS Authors
+// Copyright 2015-2022 The NATS Authors
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
 // You may obtain a copy of the License at
@@ -89,19 +89,15 @@
 #define _OK_OP_LEN_         (3)
 #define _ERR_OP_LEN_        (4)
 
-#define NATS_INBOX_PRE_LEN  (7)
+#define NATS_DEFAULT_INBOX_PRE      "_INBOX."
+#define NATS_DEFAULT_INBOX_PRE_LEN  (7)
 
-#define NATS_REQ_ID_OFFSET  (NATS_INBOX_PRE_LEN + NUID_BUFFER_LEN + 1)
 #define NATS_MAX_REQ_ID_LEN (19) // to display 2^63-1 number
 
-#define NATS_INBOX_ARRAY_SIZE   (NATS_INBOX_PRE_LEN + NUID_BUFFER_LEN + 1)
-
 #define WAIT_FOR_READ       (0)
 #define WAIT_FOR_WRITE      (1)
 #define WAIT_FOR_CONNECT    (2)
 
-#define DEFAULT_PORT_STRING "4222"
-
 #define DEFAULT_DRAIN_TIMEOUT   30000 // 30 seconds
 
 #define MAX_FRAMES (50)
@@ -135,6 +131,9 @@
 
 #define IFOK(s, c)      if (s == NATS_OK) { s = (c); }
 
+#define NATS_MILLIS_TO_NANOS(d)     (((int64_t)d)*(int64_t)1E6)
+#define NATS_SECONDS_TO_NANOS(d)    (((int64_t)d)*(int64_t)1E9)
+
 extern int64_t gLockSpinCount;
 
 typedef void (*natsInitOnceCb)(void);
@@ -306,6 +305,9 @@ struct __natsOptions
 
     // Disable the "no responders" feature.
     bool disableNoResponders;
+
+    // Custom inbox prefix
+    char *inboxPfx;
 };
 
 typedef struct __nats_MsgList
@@ -337,6 +339,7 @@ struct __jsCtx
     natsStrHash         *pm;
     natsSubscription    *rsub;
     char                *rpre;
+    int                 rpreLen;
     int                 pacw;
     int64_t             pmcount;
     int                 stalled;
@@ -351,6 +354,15 @@ typedef struct __jsSub
     bool                pull;
     bool                ordered;
     bool                dc; // delete JS consumer in Unsub()/Drain()
+    bool                ackNone;
+
+    // This is ConsumerInfo's Pending+Consumer.Delivered that we get from the
+    // add consumer response. Note that some versions of the server gather the
+    // consumer info *after* the creation of the consumer, which means that
+    // some messages may have been already delivered. So the sum of the two
+    // is a more accurate representation of the number of messages pending or
+    // in the process of being delivered to the subscription when created.
+    uint64_t            pending;
 
     int64_t             hbi;
     int64_t             active;
@@ -398,6 +410,7 @@ struct __kvStore
     char                *bucket;
     char                *stream;
     char                *pre;
+    bool                useJSPrefix;
 
 };
 
@@ -425,6 +438,8 @@ struct __kvWatcher
     int                 refs;
     kvStore             *kv;
     natsSubscription    *sub;
+    uint64_t            initPending;
+    uint64_t            received;
     bool                ignoreDel;
     bool                initDone;
     bool                retMarker;
@@ -658,6 +673,12 @@ struct __natsConnection
     int                 respPoolSize;
     int                 respPoolIdx;
 
+    // For inboxes. We now support custom prefixes, so we can't rely
+    // on constants based on hardcoded "_INBOX." prefix.
+    const char          *inboxPfx;
+    int                 inboxPfxLen;
+    int                 reqIdOffset;
+
     struct
     {
         bool            attached;
@@ -670,6 +691,14 @@ struct __natsConnection
     // Protected by subsMu
     natsMsgFilter       filter;
     void                *filterClosure;
+
+    // Server version
+    struct
+    {
+        int             ma;
+        int             mi;
+        int             up;
+    } srvVersion;
 };
 
 //
@@ -713,9 +742,6 @@ nats_sslRegisterThreadForCleanup(void);
 natsStatus
 nats_sslInit(void);
 
-natsStatus
-natsInbox_init(char *inbox, int inboxLen);
-
 natsStatus
 natsLib_msgDeliveryPostControlMsg(natsSubscription *sub);
 
