@@ -455,65 +455,101 @@ _jsonTrimSpace(char *ptr)
     return ptr;
 }
 
+static natsStatus
+_decodeUni(char **iPtr, char *val)
+{
+    int     res = 0;
+    char    *i  = *iPtr;
+    int     j;
+
+    if (strlen(i) < 5)
+        return NATS_ERR;
+
+    i++;
+    for (j=0; j<4; j++)
+    {
+        char c = i[j];
+        if ((c >= '0') && (c <= '9'))
+            c = c - '0';
+        else if ((c >= 'a') && (c <= 'f'))
+            c = c - 'a' + 10;
+        else if ((c >= 'A') && (c <= 'F'))
+            c = c - 'A' + 10;
+        else
+            return NATS_ERR;
+
+		res = (res << 4) + c;
+	}
+    *val   = (char) res;
+    *iPtr += 5;
+
+    return NATS_OK;
+}
+
 static natsStatus
 _jsonGetStr(char **ptr, char **value)
 {
     char *p = *ptr;
+    char *o = *ptr;
 
     while ((*p != '\0') && (*p != '"'))
     {
-        if ((*p == '\\') && (*(p + 1) != '\0'))
+        if (*p != '\\')
         {
+            if (o != p)
+                *o = *p;
+            o++;
             p++;
-            // based on what http://www.json.org/ says a string should be
-            switch (*p)
+            continue;
+        }
+        p++;
+        // Escaped character here...
+        if (*p == '\0')
+        {
+            *o = '\0';
+            return nats_setError(NATS_ERR,
+                                 "error parsing string '%s': invalid control character at the end",
+                                 o);
+        }
+        // based on what http://www.json.org/ says a string should be
+        switch (*p)
+        {
+            case 'b': *o++ = '\b'; break;
+            case 'f': *o++ = '\f'; break;
+            case 'n': *o++ = '\n'; break;
+            case 'r': *o++ = '\r'; break;
+            case 't': *o++ = '\t'; break;
+            case '"':
+            case '\\':
+            case '/':
+                *o++ = *p;
+                break;
+            case 'u':
             {
-                case '"':
-                case '\\':
-                case '/':
-                case 'b':
-                case 'n':
-                case 'r':
-                case 't':
-                    break;
-                case 'u':
+                char        val = 0;
+                natsStatus  s   = _decodeUni(&p, &val);
+                if (s != NATS_OK)
                 {
-                    int i;
-
-                    // Needs to be 4 hex. A hex is a digit or AF, af
-                    p++;
-                    for (i=0; i<4; i++)
-                    {
-                        // digit range
-                        if (((*p >= '0') && (*p <= '9'))
-                                || ((*p >= 'A') && (*p <= 'F'))
-                                || ((*p >= 'a') && (*p <= 'f')))
-                        {
-                            p++;
-                        }
-                        else
-                        {
-                            return nats_setError(NATS_ERR,
-                                                 "error parsing string '%s': invalid unicode character",
-                                                 p);
-                        }
-                    }
-                    p--;
-                    break;
-                }
-                default:
                     return nats_setError(NATS_ERR,
-                                         "error parsing string '%s': invalid control character",
+                                         "error parsing string '%s': invalid unicode character",
                                          p);
+                }
+                *o++ = val;
+                p--;
+                break;
             }
+            default:
+                return nats_setError(NATS_ERR,
+                                     "error parsing string '%s': invalid control character",
+                                     p);
         }
         p++;
     }
 
     if (*p != '\0')
     {
+        *o = '\0';
         *value = *ptr;
-        *p = '\0';
         *ptr = (char*) (p + 1);
         return NATS_OK;
     }
@@ -1541,6 +1577,32 @@ nats_JSONGetArrayArray(nats_JSON *json, const char *fieldName, nats_JSONArray **
     JSON_GET_ARRAY(TYPE_ARRAY, nats_JSONArrayAsArrays);
 }
 
+natsStatus
+nats_JSONRange(nats_JSON *json, int expectedType, int expectedNumType, jsonRangeCB cb, void *userInfo)
+{
+    natsStrHashIter iter;
+    char            *fname  = NULL;
+    void            *val    = NULL;
+    natsStatus      s       = NATS_OK;
+
+    natsStrHashIter_Init(&iter, json->fields);
+    while ((s == NATS_OK) && natsStrHashIter_Next(&iter, &fname, &val))
+    {
+        nats_JSONField *f = (nats_JSONField*) val;
+
+        if (f->typ != expectedType)
+            s = nats_setError(NATS_ERR, "field '%s': expected value type of %d, got %d",
+                              f->name, expectedType, f->typ);
+        else if ((f->typ == TYPE_NUM) && (f->numTyp != expectedNumType))
+            s = nats_setError(NATS_ERR, "field '%s': expected numeric type of %d, got %d",
+                              f->name, expectedNumType, f->numTyp);
+        else
+            s = cb(userInfo, (const char*) f->name, f);
+    }
+    natsStrHashIter_Done(&iter);
+    return NATS_UPDATE_ERR_STACK(s);
+}
+
 void
 nats_JSONDestroy(nats_JSON *json)
 {
@@ -1851,7 +1913,7 @@ natsStatus
 nats_Base64_Decode(const char *src, unsigned char **dst, int *dstLen)
 {
     natsStatus  s;
-    int         sl;
+    int         sl = 0;
 
     *dst = NULL;
     *dstLen = 0;
@@ -1931,9 +1993,10 @@ nats_ReadFile(natsBuffer **buffer, int initBufSize, const char *fn)
     else if (fclose(f) != 0)
         s = nats_setError(NATS_ERR, "error closing file '%s': '%s", fn, strerror(errno));
 
+    IFOK(s, natsBuf_AppendByte(buf, '\0'));
+
     if (s == NATS_OK)
     {
-        natsBuf_AppendByte(buf, '\0');
         *buffer = buf;
     }
     else if (buf != NULL)
@@ -2139,3 +2202,58 @@ nats_marshalULong(natsBuffer *buf, bool comma, const char *fieldName, uint64_t u
     natsStatus s = _marshalLongVal(buf, comma, fieldName, false, 0, uval);
     return NATS_UPDATE_ERR_STACK(s);
 }
+
+
+bool
+nats_IsSubjectValid(const char *subject, bool wcAllowed)
+{
+    int     i       = 0;
+    int     len     = 0;
+    int     lastDot = -1;
+    char    c;
+
+    if (nats_IsStringEmpty(subject))
+        return false;
+
+    len = (int) strlen(subject);
+    for (i=0; i<len ; i++)
+    {
+        c = subject[i];
+        if (isspace(c))
+            return false;
+
+        if (c == '.')
+        {
+            if ((i == len-1) || (i == lastDot+1))
+                return false;
+
+            // If the last token was 1 character long...
+            if (i == lastDot+2)
+            {
+                char prevToken = subject[i-1];
+
+                // If that token was `>`, then it is not a valid subject,
+                // regardless if wildcards are allowed or not.
+                if (prevToken == '>')
+                    return false;
+                else if (!wcAllowed && (prevToken == '*'))
+                    return false;
+            }
+
+            lastDot = i;
+        }
+
+        // Check the last character to see if it is a wildcard. Others
+        // are handled when processing the next '.' character (since
+        // if not a token of their own, they are not considered wildcards).
+        if (i == len-1)
+        {
+            // If they are a token of their own, that is, the preceeding
+            // character is the `.` or they are the first and only character,
+            // then the result will depend if wilcards are allowed or not.
+            if (((c == '>') || (c == '*')) && (i == lastDot+1))
+                return wcAllowed;
+        }
+    }
+    return true;
+}
